Method: Azure::StreamAnalytics::Mgmt::V2016_03_01::Models::BlobOutputDataSource#path_pattern

Defined in:
lib/2016-03-01/generated/azure_mgmt_stream_analytics/models/blob_output_data_source.rb

#path_patternString

represents a pattern against which blob names will be matched to determine whether or not they should be included as input or output to the job. See docs.microsoft.com/en-us/rest/api/streamanalytics/stream-analytics-input or docs.microsoft.com/en-us/rest/api/streamanalytics/stream-analytics-output for a more detailed explanation and example.

Returns:

  • (String)

    The blob path pattern. Not a regular expression. It



39
40
41
# File 'lib/2016-03-01/generated/azure_mgmt_stream_analytics/models/blob_output_data_source.rb', line 39

def path_pattern
  @path_pattern
end