Class: Azure::StreamAnalytics::Mgmt::V2016_03_01::Models::PowerBIOutputDataSource

Inherits:
OutputDataSource
  • Object
show all
Includes:
MsRestAzure
Defined in:
lib/2016-03-01/generated/azure_mgmt_stream_analytics/models/power_bioutput_data_source.rb

Overview

Describes a Power BI output data source.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initializePowerBIOutputDataSource

Returns a new instance of PowerBIOutputDataSource.



16
17
18
# File 'lib/2016-03-01/generated/azure_mgmt_stream_analytics/models/power_bioutput_data_source.rb', line 16

def initialize
  @type = "PowerBI"
end

Instance Attribute Details

#datasetString

(CreateOrReplace) requests.

Returns:

  • (String)

    The name of the Power BI dataset. Required on PUT



43
44
45
# File 'lib/2016-03-01/generated/azure_mgmt_stream_analytics/models/power_bioutput_data_source.rb', line 43

def dataset
  @dataset
end

#group_idString

Returns The ID of the Power BI group.

Returns:

  • (String)

    The ID of the Power BI group.



50
51
52
# File 'lib/2016-03-01/generated/azure_mgmt_stream_analytics/models/power_bioutput_data_source.rb', line 50

def group_id
  @group_id
end

#group_nameString

help remember which specific Power BI group id was used.

Returns:

  • (String)

    The name of the Power BI group. Use this property to



54
55
56
# File 'lib/2016-03-01/generated/azure_mgmt_stream_analytics/models/power_bioutput_data_source.rb', line 54

def group_name
  @group_name
end

#refresh_tokenString

access token that can then be used to authenticate with the data source. A valid refresh token is currently only obtainable via the Azure Portal. It is recommended to put a dummy string value here when creating the data source and then going to the Azure Portal to authenticate the data source which will update this property with a valid refresh token. Required on PUT (CreateOrReplace) requests.

Returns:

  • (String)

    A refresh token that can be used to obtain a valid



29
30
31
# File 'lib/2016-03-01/generated/azure_mgmt_stream_analytics/models/power_bioutput_data_source.rb', line 29

def refresh_token
  @refresh_token
end

#tableString

dataset. Required on PUT (CreateOrReplace) requests.

Returns:

  • (String)

    The name of the Power BI table under the specified



47
48
49
# File 'lib/2016-03-01/generated/azure_mgmt_stream_analytics/models/power_bioutput_data_source.rb', line 47

def table
  @table
end

#token_user_display_nameString

obtain the refresh token. Use this property to help remember which user was used to obtain the refresh token.

Returns:

  • (String)

    The user display name of the user that was used to



39
40
41
# File 'lib/2016-03-01/generated/azure_mgmt_stream_analytics/models/power_bioutput_data_source.rb', line 39

def token_user_display_name
  @token_user_display_name
end

#token_user_principal_nameString

used to obtain the refresh token. Use this property to help remember which user was used to obtain the refresh token.

Returns:

  • (String)

    The user principal name (UPN) of the user that was



34
35
36
# File 'lib/2016-03-01/generated/azure_mgmt_stream_analytics/models/power_bioutput_data_source.rb', line 34

def token_user_principal_name
  @token_user_principal_name
end

#typeObject

Returns the value of attribute type.



20
21
22
# File 'lib/2016-03-01/generated/azure_mgmt_stream_analytics/models/power_bioutput_data_source.rb', line 20

def type
  @type
end

Class Method Details

.mapperObject

Mapper for PowerBIOutputDataSource class as Ruby Hash. This will be used for serialization/deserialization.



61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
# File 'lib/2016-03-01/generated/azure_mgmt_stream_analytics/models/power_bioutput_data_source.rb', line 61

def self.mapper()
  {
    client_side_validation: true,
    required: false,
    serialized_name: 'PowerBI',
    type: {
      name: 'Composite',
      class_name: 'PowerBIOutputDataSource',
      model_properties: {
        type: {
          client_side_validation: true,
          required: true,
          serialized_name: 'type',
          type: {
            name: 'String'
          }
        },
        refresh_token: {
          client_side_validation: true,
          required: false,
          serialized_name: 'properties.refreshToken',
          type: {
            name: 'String'
          }
        },
        token_user_principal_name: {
          client_side_validation: true,
          required: false,
          serialized_name: 'properties.tokenUserPrincipalName',
          type: {
            name: 'String'
          }
        },
        token_user_display_name: {
          client_side_validation: true,
          required: false,
          serialized_name: 'properties.tokenUserDisplayName',
          type: {
            name: 'String'
          }
        },
        dataset: {
          client_side_validation: true,
          required: false,
          serialized_name: 'properties.dataset',
          type: {
            name: 'String'
          }
        },
        table: {
          client_side_validation: true,
          required: false,
          serialized_name: 'properties.table',
          type: {
            name: 'String'
          }
        },
        group_id: {
          client_side_validation: true,
          required: false,
          serialized_name: 'properties.groupId',
          type: {
            name: 'String'
          }
        },
        group_name: {
          client_side_validation: true,
          required: false,
          serialized_name: 'properties.groupName',
          type: {
            name: 'String'
          }
        }
      }
    }
  }
end